@@ -35,7 +35,7 @@ class notion_connector:
 #############################################
 	def helper(self):
 		print('[NOTION CONNECTOR] All function available :')
-		print("\t- \"put_in_file([data],[*name])\" -> Will put the data in file, if name param was given, file will take the name, else file will be name output.json."))
+		print("\t- \"put_in_file([data],[*name])\" -> Will put the data in file, if name param was given, file will take the name, else file will be name output.json.")
 		print("\t- \"getDb(dbId)\" -> Activate verbose.")
 		print("\t- \"updateDb(pageId, data)\" -> Activate verbose.")
 		print("\t- \"createDb(parentId)\" -> Activate verbose.")
