@@ -4,21 +4,21 @@ class update_properties:
 	def __init__(self, **kwargs):
 		self.users = kwargs['users_list']
 
-	def build_text(self, elem):
+	def build_text(self, text):
 		data = {
 					"annotations": {
-					"bold": false,
-					"code": false,
+					"bold": False,
+					"code": False,
 					"color": "default",
-					"italic": false,
-					"strikethrough": false,
-					"underline": false
+					"italic": False,
+					"strikethrough": False,
+					"underline": False
 				},
-					"href": null,
-					"plain_text": elem['text'],
+					"href": None,
+					"plain_text": text,
 					"text": {
-					"content": elem['text'],
-					"link": null
+					"content": text,
+					"link": None
 				},
 				"type": "text"
 			}
@@ -45,7 +45,7 @@ class update_properties:
 				elem['properties']['title'][0]['plain_text'] = elem['text']
 				elem['properties']['title'][0]['text']['content'] = elem['text']
 			else :
-				elem['properties']['title'].append(self.build_text(elem))
+				elem['properties']['title'].append(self.build_text(elem['title']))
 		return elem
 
 	def update_rich_text(self, elem):
@@ -54,7 +54,7 @@ class update_properties:
 				elem['properties']['rich_text'][0]['plain_text'] = elem['text']
 				elem['properties']['rich_text'][0]['text']['content'] = elem['text']
 			else :
-				elem['properties']['rich_text'].append(self.build_text(elem))
+				elem['properties']['rich_text'].append(self.build_text(elem['rich_text']))
 		return elem
 
 	def update_date(self, elem):
